@@ -22,6 +22,7 @@ import gdata.calendar.service
 import gdata.service
 import atom.service
 import gdata.calendar
+import gobject
 import atom
 
 icon_path = "/usr/share/pixmaps/mgcal/"
@@ -37,10 +38,12 @@ class mgCal(hildondesktop.HomeItem):
         hildondesktop.HomeItem.__init__(self)
 
         self._GetConfig()
-
+        self.Timer = None
+        self.UpdateTimer = None
         self.connect("settings",self.SettingsMenu)
         self.connect("unrealize",self.Unrealize)
-
+        self.connect("background", self._Background)
+        self.connect("foreground", self._Foreground)
         self.vbox = gtk.VBox(False,0)
         self.add(self.vbox)
 
@@ -110,7 +113,7 @@ class mgCal(hildondesktop.HomeItem):
         self.set_resize_type(hildondesktop.HOME_ITEM_RESIZE_BOTH)
         self._Refresh(self)
         self.show_all()
-
+        self._InitTimer()
 
     ################################################
     # handle the settings menu by returning
@@ -228,6 +231,7 @@ class mgCal(hildondesktop.HomeItem):
             self.db.commit()
             self.db.close()
         # bye bye...
+        self._resetUpdateTimer()
         dlgS.destroy()
 
 
@@ -249,6 +253,7 @@ class mgCal(hildondesktop.HomeItem):
         self.data_start = 0
         self._GetEvents()
         self._DrawEvents()
+        self._resetUpdateTimer()
 
 
     ################################################
@@ -315,7 +320,7 @@ class mgCal(hildondesktop.HomeItem):
             # set updated time
             self.db = sqlite3.connect(db_path + db_name)
             hdate = datetime.datetime.strptime(self.db.execute("""select hdatetime from history order by hdatetime desc limit 1""").fetchall()[0][0],'%Y-%m-%d %H:%M:%S')
-            self.lbltop.set_markup(hdate.strftime("<b>Updated: %a, %d %b   %H:%M</b>"))
+#            self.lbltop.set_markup(hdate.strftime("<b>Updated: %a, %d %b   %H:%M</b>"))
             # and off we go...
             c = self.db.cursor()
             c.execute("select start,end,title,location from events order by start,end limit -1 offset ?",[self.data_start])
@@ -374,11 +379,38 @@ class mgCal(hildondesktop.HomeItem):
             self._DrawEvents()
         return True
 
+    def _Background(self, widget):
+        gobject.source_remove(self.Timer)
+        self.Timer = None
+
+    def _Foreground(self, widget):
+        if self.Timer != None:
+            gobject.source_remove(self.Timer)
+        self.Timer = gobject.timeout_add(60000, self._UpdateTime)
+        self._UpdateTime()
+
+    def _InitTimer(self):
+        if self.Timer != None:
+            gobject.source_remove(self.Timer)
+        self.Timer = gobject.timeout_add(60000, self._UpdateTime)
+        self._UpdateTime()
+
+    def _UpdateTime(self):
+        self.lbltop.set_markup(datetime.datetime.now().strftime("<b>%d. %b %Y  %I:%M</b>"))
+        return True
+    
+    def _resetUpdateTimer(self):
+        if self.UpdateTimer != None:
+            gobject.source_remove(self.UpdateTimer)
+        if self.cfg_refresh != 0:
+            self.UpdateTimer = gobject.timeout_add(3600 * 1000 * self.cfg_refresh, self._UpdateDb)
+        else:
+            self.UpdateTimer = None
+
+    def _UpdateDb(self):
+        self._Refresh(self)
+        return True
 
 def hd_plugin_get_objects():
     plugin = mgCal()
     return [plugin]
-
-
-
-
